@@ -1,6 +1,7 @@
 import re
 import ast
 import _ast
+import codegen
 
 
 # Local imports
@@ -27,6 +28,8 @@ def __split(buffer):
 
     points = []
 
+    in_str = False
+
     for idx in xrange(0, len(buffer)):
 
         char = buffer[idx]
@@ -39,6 +42,16 @@ def __split(buffer):
 
             depth = depth - 1
 
+        if char == '"' or char == "'":
+
+            if in_str:
+
+                depth = depth - 1
+
+            else:
+
+                depth = depth + 1
+
         if char == ',' and depth == 0:
 
             points.append(idx)
@@ -122,6 +135,7 @@ def preprocessor(buffer, stmt_as_is, tries=0):
     # For each item in [], preprocess item (recursive)
     # For each item in (), preprocess item (recursive)
     # For each function address, preprocess function_address, return __builtins__.remotefunction()
+    # For each trailing &, return __builtins__.attributedcode()
 
     ##########
     # PYTHON #
@@ -189,9 +203,7 @@ def preprocessor(buffer, stmt_as_is, tries=0):
 
                 if node.values:
 
-                    # i.e. "print_(...)"
-
-                    new_buffer = '__builtins__.print_(\'' + node.values[0].s + '\')'
+                    new_buffer = '__builtins__.print_(' + codegen.to_source(node)[5:] + ')'
 
                 # It's (a) Python and (b) expression
 
@@ -307,7 +319,7 @@ def preprocessor(buffer, stmt_as_is, tries=0):
 
             fcn_name = fcn_name.split('(')[0]
 
-            new_buffer = new_buffer.replace(function_address, '__builtins__.remotefunction(\'' + fcn_name + '\',\'' + fcn_host + '\')(' + fcn_args + ')')
+            new_buffer = new_buffer.replace(function_address, '__builtins__.remotefunction(\'' + fcn_name + '\',\'' + fcn_host + '\',' + fcn_args + ')')
 
         # foobar@xmlrpc://...
 
@@ -315,6 +327,18 @@ def preprocessor(buffer, stmt_as_is, tries=0):
 
             new_buffer = new_buffer.replace(function_address, '__builtins__.remotefunction(\'' + fcn_name + '\',\'' + fcn_host + '\')')
 
+    # Change Provider to Process?
+
+    if new_buffer.rstrip()[-1] == '&':
+
+        new_buffer = new_buffer.rstrip()[:-1]
+
+        actual_buffer = preprocessor(new_buffer, stmt_as_is, tries)
+
+        # Assume new_buffer is from PYTHON_EXPRESSION
+
+        new_buffer = '__builtins__.attributedcode("(operator, \'%s\')", "(iterate_literal_arrays, multiprocessing.Process, multiprocessing.Queue)")' % actual_buffer[1]
+
     # Try again!
 
     return preprocessor(new_buffer, stmt_as_is, tries + 1)
